# Galician translation for zim
# Copyright (c) 2008 Rosetta Contributors and Canonical Ltd 2008
# This file is distributed under the same license as the zim package.
# FIRST AUTHOR <EMAIL@ADDRESS>, 2008.
# 
# 
# TRANSLATORS:
# Roberto Suarez (gl)
# marisma (gl)
# 
# Project-Id-Version: zim
# Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
# POT-Creation-Date: 2008-10-27 21:09+0100
# PO-Revision-Date: 2008-08-28 16:49+0000
# Last-Translator: Roberto Suarez <robe@allenta.com>
# Language-Team: Galician <gl@li.org>
# MIME-Version: 1.0
# Content-Type: text/plain; charset=UTF-8
# Content-Transfer-Encoding: 8bit
# Plural-Forms: nplurals=2; plural=n != 1;
# X-Launchpad-Export-Date: 2008-11-09 09:04+0000
# X-Generator: Launchpad (build Unknown)

use utf8;

# Subroutine to determine plural:
sub {my $n = shift; $n != 1},

# Hash with translation strings:
{
  '%a %b %e %Y' => '%a %b %e %Y',
  '<b>Delete page</b>

Are you sure you want to delete
page \'{name}\' ?' => '<b>Borrar páxina</b>

¿Está seguro de querer borrar
a páxina \'{name}\'?',
  '<b>Enable Version Control</b>

Version control is currently not enabled for this notebook.
Do you want to enable it ?' => '<b>Activar o Control de Versións</b>',
  '<b>Folder does not exist.</b>

The folder: {path}
does not exist, do you want to create it now?' => '<b>A carpeta non existe.</b>

A carpeta {path}
non existe, ¿quere que se cree agora?',
  '<b>Page already exists</b>

The page \'{name}\'
already exists.
Do you want to overwrite it?' => '<b>A páxina xa existe</b>

A páxina \'{name}\'
xa existe.
¿Desexa escribir por encima?',
  '<b>Restore page to saved version?</b>

Do you want to restore page: {page}
to saved version: {version} ?

All changes since the last saved version will be lost !' => '',
  '<b>Upgrade calendar pages to 0.24 format?</b>

This notebook contains pages for dates using the format yyyy_mm_dd.
Since Zim 0.24 the format yyyy:mm:dd is used by default, creating
namespaces per month.

Do you want to upgrade this notebook to the new layout?
' => '<b>¿Actualizar as páxinas ó formato da versión 0.24?</b>

Este caderno contén páxinas para dataas que usan o formato aaaa_mm_dd.
Dende Zim 0.24 úsase o formato aaaa:mm:dd por defecto, creando
espacios por mes.

¿Desexa actualizar este caderno ó novo esquema?
',
  'Add \'tearoff\' strips to the menus' => 'Engadir barras para desprender os menúes',
  'Application show two text files side by side' => 'Aplicación para amosar dous ficheiros de texto simultaneamente',
  'Application to compose email' => 'Aplicación de correo electrónico',
  'Application to edit text files' => 'Aplicación para editar ficheiros de texto',
  'Application to open directories' => 'Aplicación para abrir directorios',
  'Application to open urls' => 'Aplicación para abrir urls',
  'Attach _File|Attach external file' => 'Anexar _ficheiro|Anexar un ficheiro externo',
  'Attach external files' => 'Adxuntar ficheiros externos',
  'Auto-format entities' => 'Formato automático de entidades',
  'Auto-increment numbered lists' => 'Incrementar automáticamente as listas enumeradas',
  'Auto-link CamelCase' => 'Auto-ligar CamelCase',
  'Auto-link files' => 'Auto-ligar ficheiros',
  'Auto-save version on close' => 'Gardar versión automáticamente ó saír',
  'Auto-select words' => 'Seleccionar palabras automáticamente',
  'Automatically increment items in a numbered list' => 'Incrementar automáticamente os artigos nunha lista enumerada',
  'Automatically link file names when you type' => 'Ligar ficheiros automáticamente cando se escriben',
  'Automaticly link CamelCase words when you type' => 'Ligar automáticamente as palabras en CamelCase cando se escriben',
  'Automaticly select the current word when you toggle the format' => 'Seleccionar automáticamente a palabra actual cando cambia o formato',
  'Bold' => 'Negriña',
  'Calen_dar|Show calendar' => 'Calen_dario|Amosar calendario',
  'Calendar' => 'Calendario',
  'Can not find application "bzr"' => '',
  'Can not find application "{name}"' => '',
  'Can not save a version without comment' => 'Non está permitido gardar unha versión sin comentario',
  'Can not save to page: {name}' => 'Non se puido gardar á páxina: {name}',
  'Can\'t find {url}' => 'Non se pode atopar {url}',
  'Cha_nge' => 'Ca_mbiar',
  'Chars' => 'Caracteres',
  'Check _spelling|Spell check' => 'Comprobar _ortografía|Comprobación da ortografía',
  'Check checkbox lists recursive' => '',
  'Checking a checkbox list item will also check any sub-items' => '',
  'Choose {app_type}' => 'Escolla {app_type}',
  'Co_mpare Page...' => 'Co_mparar Páxina...',
  'Command' => 'Comando',
  'Comment' => '',
  'Compare this version with' => 'Comparar esta versión con',
  'Copy Email Address' => 'Copiar Enderezo de Correo-e',
  'Copy Location|Copy location' => 'Copiar ubicación|Copiar ubicación',
  'Copy _Link' => 'Copiar _Ligazón',
  'Could not delete page: {name}' => 'Non foi posible borrar a páxina: {name}',
  'Could not get annotated source for page {page}' => 'Non foi posible recuperar a fonte anotada para a páxina {page}',
  'Could not get changes for page: {page}' => 'Non foi posible recuperar os cambios para a páxina: {page}',
  'Could not get changes for this notebook' => '',
  'Could not get file for page: {page}' => 'Non foi posible recuperar o ficheiro para a páxina: {page}',
  'Could not get versions to compare' => 'Non foi posible recuperar as versións para comparar',
  'Could not initialize version control' => 'Non foi posible inicializar o sistema de control de versións',
  'Could not load page: {name}' => 'Non se puido cargar a páxina: {name}',
  'Could not rename {from} to {to}' => 'Non foi posible cambiar o nome de {from} a {to}',
  'Could not save page' => 'Non foi posible gardar a páxina',
  'Could not save version' => 'Non foi posible gardar a versión',
  'Creating a new link directly opens the page' => 'Crear unha nova ligazón abre directamente a páxina',
  'Creation Date' => 'Data de Creación',
  'Cu_t|Cut' => '_Cortar|Cortar',
  'Current' => 'Actual',
  'Customise' => 'Personalizar',
  'Date' => 'Data',
  'Default notebook' => 'Caderno por defecto',
  'Details' => 'Detalles',
  'Diff Editor' => 'Editor de diferencias',
  'Diff editor' => 'Editor de diferencias',
  'Directory' => 'Directorio',
  'Document Root' => 'Raíz dos documentos',
  'E_quation...|Insert equation' => 'E_cuación...|Inserir ecuación',
  'E_xport...|Export' => 'E_xportar...|Exportar',
  'E_xternal Link...|Insert external link' => 'Enlace e_xterno...|Insertar enlace externo',
  'Edit Image' => 'Editar imaxe',
  'Edit Link' => 'Editar Ligazón',
  'Edit Query' => 'Editar consulta',
  'Edit _Source|Open source' => 'Ed_itar o código|Abrir o código',
  'Edit notebook' => 'Editar caderno',
  'Edit text files "wiki style"' => 'Editor de texto "ó xeito Wiki"',
  'Editing' => 'Edición',
  'Email client' => 'Programa de correo electrónico',
  'Enabled' => 'Activado',
  'Equation Editor' => 'Editor de ecuacións',
  'Equation Editor Log' => 'Rexistro do Editor de Ecuacións',
  'Expand side pane' => 'Expandir panel lateral',
  'Export page' => 'Exportar páxina',
  'Exporting page {number}' => 'Exportando páxina {number}',
  'Failed to cleanup SVN working copy.' => '',
  'Failed to load SVN plugin,
do you have subversion utils installed?' => '',
  'Failed to load plugin: {name}' => 'Fallou a carga do plugin: {name}',
  'Failed update working copy.' => '',
  'File browser' => 'Navegador de ficheiros',
  'File is not a text file: {file}' => 'O ficheiro non é un ficheiro de texto: {file}',
  'Filter' => 'Filtrar',
  'Find' => 'Procurar',
  'Find Ne_xt|Find next' => 'Procurar pró_ximo|Procurar próximo',
  'Find Pre_vious|Find previous' => 'Procurar _anterior|Procurar anterior',
  'Find and Replace' => 'Buscar e Substituír',
  'Find what' => 'Palabras a atopar',
  'Follow new link' => 'Seguir unha nova ligazón',
  'For_mat|' => 'For_mato|',
  'Format' => 'Formato',
  'General' => 'Xeral',
  'Go to "{link}"' => 'Ir a "{link}"',
  'H_idden|.' => '_Oculto|.',
  'Head _1|Heading 1' => 'Cabeceira _1|Cabeceira 1',
  'Head _2|Heading 2' => 'Cabeceira _2|Cabeceira 2',
  'Head _3|Heading 3' => 'Cabeceira _3|Cabeceira 3',
  'Head _4|Heading 4' => 'Cabeceira _4|Cabeceira 4',
  'Head _5|Heading 5' => 'Cabeceira _5|Cabeceira 5',
  'Head1' => 'Cabeceira1',
  'Head2' => 'Cabeceira2',
  'Head3' => 'Cabeceira3',
  'Head4' => 'Cabeceira4',
  'Head5' => 'Cabeceira5',
  'Height' => 'Alto',
  'Home Page' => 'Páxina de inicio',
  'Icon' => 'Icono',
  'Id' => 'Id',
  'Include all open checkboxes' => '',
  'Index page' => 'Páxina de Índice',
  'Initial version' => 'Versión inicial',
  'Insert Date' => 'Inserir data',
  'Insert Image' => 'Inserir unha Imaxe',
  'Insert Link' => 'Inserir unha ligazón',
  'Insert from file' => 'Inserir desde un ficheiro',
  'Interface' => 'Interface',
  'Italic' => 'Cursiva',
  'Jump to' => 'Saltar a',
  'Jump to Page' => 'Saltar a Páxina',
  'Lines' => 'Liñas',
  'Links to' => 'Ligazóns con',
  'Match c_ase' => '_Distinguir maiúsculas e minúsculas',
  'Media' => 'Medio',
  'Modification Date' => 'Data de Modificación',
  'Name' => 'Nome',
  'New notebook' => 'Novo caderno',
  'New page' => 'Nova páxina',
  'No such directory: {name}' => 'Non hai tal directorio: {name}',
  'No such file or directory: {name}' => '',
  'No such file: {file}' => 'Non hai tal ficheiro: {file}',
  'No such notebook: {name}' => 'Non hai tal caderno: {name}',
  'No such page: {page}' => 'Non existe tal páxina: {page}',
  'No such plugin: {name}' => 'Non hai tal plugin: {name}',
  'Normal' => 'Normal',
  'Not Now' => 'Agora non',
  'Not a valid page name: {name}' => 'Non é un nome válido de páxina: {name}',
  'Not an url: {url}' => 'Non é un url válido: {url}',
  'Note that linking to a non-existing page
also automatically creates a new page.' => 'Lembre que enlazar a unha páxina non existente
crea unha nova páxina.',
  'Notebook' => 'Caderno',
  'Notebooks' => 'Cadernos',
  'Open Document _Folder|Open document folder' => 'Abrir _Carpeta de Documentos|Abrir Carpeta de Documentos',
  'Open Document _Root|Open document root' => 'Abrir _Raíz de Documentos|Abrir Raíz de Documentos',
  'Open _Directory' => 'Abrir _directorio',
  'Open notebook' => 'Abrir caderno',
  'Other...' => 'Outro...',
  'Output' => 'Saída',
  'Output dir' => 'Directorio de saída',
  'P_athbar type|' => 'Tipo de b_arra de rutas',
  'Page' => 'Páxina',
  'Page Editable|Page editable' => 'Páxina editable|Páxina editable',
  'Page name' => 'Nome da páxina',
  'Pages' => 'Páxinas',
  'Password' => '',
  'Please enter a comment for this version' => 'Por favor, introduza un comentario para esta versión',
  'Please enter a name to save a copy of page: {page}' => 'Por favor, introduza un nome para gardar a copia da páxina: {page}',
  'Please enter a {app_type}' => 'Por favor, introduza un {app_type}',
  'Please give a page first' => 'Por favor, introduza unha páxina primeiro',
  'Please give at least a directory to store your pages.
For a new notebook this should be an empty directory.
For example a "Notes" directory in your home dir.' => 'Por favor, indique como mínimo un directorio
onde gardar as súas páxinas. Para un novo caderno
isto debería ser un directorio baleiro. Por exemplo,
un directorio chamado "Notas" no seu directorio
de inicio.',
  'Please provide the password for
{path}' => '',
  'Please select a notebook first' => 'Por favor, seleccione un caderno primeiro',
  'Please select a version first' => 'Seleccione unha versión primeiro',
  'Plugin already loaded: {name}' => 'Plugin xa cargado: {name}',
  'Plugins' => 'Extensións',
  'Pr_eferences|Preferences dialog' => 'Pre_ferencias|Preferencias',
  'Preferences' => 'Preferencias',
  'Prefix document root' => 'Prefixo do raíz de documentos',
  'Print to Browser|Print to browser' => 'Imprimir ó navegador|Imprimir ó navegador',
  'Prio' => 'Prioridade',
  'Proper_ties|Properties dialog' => 'Propie_dades|Propiedades',
  'Properties' => 'Propiedades',
  'Rank' => 'Clasificación',
  'Re-build Index|Rebuild index' => 'Reconstruir Índice|Reconstruir Índice',
  'Recursive' => 'Recursivo',
  'Rename page' => 'Renomear páxina',
  'Rename to' => 'Renomear como',
  'Replace _all' => 'Substituír _todo',
  'Replace with' => 'Substituír por',
  'SVN cleanup|Cleanup SVN working copy' => '',
  'SVN commit|Commit notebook to SVN repository' => '',
  'SVN update|Update notebook from SVN repository' => '',
  'S_ave Version...|Save Version' => '_Gardar Versión...|Gardar Versión',
  'Save Copy' => 'Gardar copia',
  'Save version' => 'Gardar versión',
  'Scanning tree ...' => 'Buscando na árbore...',
  'Search' => 'Procurar',
  'Search _Backlinks...|Search Back links' => 'Buscar ligazón_s de inversas...|Buscar ligazóns inversas',
  'Select File' => 'Escoller Ficheiro',
  'Select Folder' => 'Seleccionar Cartafol',
  'Send To...' => 'Enviar a...',
  'Show cursor for read-only' => 'Amosar o cursor en modo de só lectura',
  'Show the cursor even when you can not edit the page. This is useful for keyboard based browsing.' => 'Amosar o cursor aínda que non se poda editar a páxina.
Esto é útil para navegar usando o teclado.',
  'Slow file system' => 'Sistema de ficheiros lento',
  'Source' => 'Orixe',
  'Source Format' => 'Formato orixinal',
  'Start the side pane with the whole tree expanded.' => 'Comezar coa árbore do panel lateral expandida',
  'Stri_ke|Strike' => '_Tachado|Tachado',
  'Strike' => 'Tachado',
  'TODO List' => 'Lista de tarefas ("TODO")',
  'Task' => 'Tarefa',
  'Tearoff menus' => 'Menúes desprendibles',
  'Template' => 'Modelo',
  'Text' => 'Texto',
  'Text Editor' => 'Editor de textos',
  'Text _From File...|Insert text from file' => 'Texto desde _ficheiro...|Insertar texto desde un ficheiro',
  'Text editor' => 'Editor de textos',
  'The equation failed to compile. Do you want to save anyway?' => 'Fallou a compilación da ecuación. ¿Desexa gardar aínda así?',
  'The equation for image: {path}
is missing. Can not edit equation.' => 'A ecuación para a imaxe: {path}
non existe. Non se pode editar a ecuación.',
  'This notebook does not have a document root' => 'Este caderno non ten un documento raíz',
  'This page does not exist
404' => 'Esta páxina non existe
404',
  'This page does not have a document folder' => 'Esta páxina non ten unha carpeta de documentos',
  'This page does not have a source' => 'Esta páxina non ten fonte',
  'This page was updated in the repository.
Please update your working copy (Tools -> SVN update).' => '',
  'To_day|Today' => '_Hoxe|Hoxe',
  'Toggle Checkbox \'V\'|Toggle checkbox' => '',
  'Toggle Checkbox \'X\'|Toggle checkbox' => '',
  'Underline' => 'Subliñado',
  'Updating links' => 'Actualizando enlaces',
  'Updating links in {name}' => 'Actualizando enlaces en {name}',
  'Updating..' => 'Actualizando ...',
  'Use "Backspace" to un-indent' => 'Usar "Borrar" para quitar a sangría',
  'Use "Ctrl-Space" to switch focus' => 'Usar "Control-Espacio" para cambiar o enfoque',
  'Use "Enter" to follow links' => 'Usar "Enter" para seguir ligazóns',
  'Use autoformatting to type special characters' => 'Usar formato automático para teclear caracteres especiais',
  'Use custom font' => 'Usar un tipo de letra personalizado',
  'Use the "Backspace" key to un-indent bullet lists (Same as "Shift-Tab")' => 'Usar a tecla de "Borrar" (en inglés, "Backspace") para quitar
a sangría dos elementos de listas de puntos (o mesmo que "Shift-Tab")',
  'Use the "Ctrl-Space" key combo to switch focus between text and side pane. If disabled you can still use "Alt-Space".' => 'Use a combinación "Control-Espacio" para cambiar o enfoque entre o texto e o panel lateral.
Se non se activa esta opción, sempre pode usar "Alt-Espacio".',
  'Use the "Enter" key to follow links. If disabled you still can use "Alt-Enter"' => 'Use a tecla "Enter" para seguir ligazóns. Se non se activa esta opción,
sempre pode usar "Alt-Enter".',
  'User' => 'Usuario',
  'User name' => 'Nome de usuario',
  'Verbatim' => 'Verbatim',
  'Versions' => 'Versións',
  'View _Annotated...' => 'Ver _Anotacións...',
  'View _Log' => 'Ver _rexistro',
  'Web browser' => 'Navegador web',
  'Whole _word' => 'Palabras _enteiras',
  'Width' => 'Ancho',
  'Word Count' => 'Cantidade de palabras',
  'Words' => 'Palabras',
  'You can add rules to your search query below' => 'Pode engadir regras para a súa consulta abaixo',
  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
Please click \'help\' to read about the system requirements.' => '',
  'You have no {app_type} configured' => 'Non ten un {app_type} configurado',
  'You need to restart the application
for plugin changes to take effect.' => 'Necesita reiniciar a aplicación
para que os cambios das extensións
fagan efecto.',
  'Your name; this can be used in export templates' => 'O seu nome; esto pode ser usado nos patróns de exportación',
  'Zim Desktop Wiki' => 'Wiki Personal Zim',
  '_About|About' => '_Acerca de|Acerca do programa',
  '_All' => '_Todo',
  '_Back|Go page back' => 'Rec_uar|Ir á páxina anterior',
  '_Bold|Bold' => 'N_egrita|Negrita',
  '_Browse...' => 'E_xaminar...',
  '_Bugs|Bugs' => '_Bugs|Erros de programación',
  '_Child|Go to child page' => '_Descender|Ir á páxina inferior',
  '_Close|Close window' => 'Pe_char|Pechar ventá',
  '_Contents|Help contents' => '_Contidos|Contidos da axuda',
  '_Copy Page...|Copy page' => '_Copiar Páxina...|Copiar páxina',
  '_Copy|Copy' => '_Copiar|Copiar',
  '_Date and Time...|Insert date' => '_Data e hora...|Inserir data',
  '_Delete Page|Delete page' => 'E_liminar páxina|Eliminar páxina',
  '_Delete|Delete' => '_Borrar|Borrar',
  '_Discard changes' => '_Descartar cambios',
  '_Edit' => '',
  '_Edit Equation' => '_Editar Ecuación',
  '_Edit Link' => '_Editar ligazón',
  '_Edit Link...|Edit link' => '_Editar ligazón...|Editar ligazón',
  '_Edit|' => '_Editar|',
  '_FAQ|FAQ' => '_FAQ|Preguntas Máis Frecuentes',
  '_File|' => '_Ficheiro|',
  '_Filter' => '_Filtrar',
  '_Find...|Find' => '_Procurar...|Procurar',
  '_Forward|Go page forward' => 'A_diante|Ir á vindeira páxina',
  '_Go|' => 'I_r|',
  '_Help|' => 'A_xuda|',
  '_History|.' => '_Histórico|.',
  '_Home|Go home' => '_Inicio|Ir á páxina de inicio',
  '_Image...|Insert image' => '_Imaxe...|Insertar imaxe',
  '_Index|Show index' => 'Í_ndice|Amosar o índice',
  '_Insert' => '_Inserir',
  '_Insert|' => '_Inserir|',
  '_Italic|Italic' => '_Cursiva|Cursiva',
  '_Jump To...|Jump to page' => '_Ir a...|Ir á páxina',
  '_Keybindings|Key bindings' => 'Ata_llos de teclado|Atallos de teclado',
  '_Link' => '_Ligazón',
  '_Link to date' => '_Enlazar á data',
  '_Link...|Insert link' => '_Ligazón...|Inserir ligazón',
  '_Link|Link' => '_Ligazón|Ligazón',
  '_Namespace|.' => 'Espacio de _Nomes|.',
  '_New Page|New page' => '_Nova páxina|Nova páxina',
  '_Next' => '_Seguinte',
  '_Next in index|Go to next page' => '_Vindeira no índice|Ir á vindeira páxina',
  '_Normal|Normal' => '_Normal|Normal',
  '_Notebook Changes...' => 'Cambios no _caderno ...',
  '_Open Another Notebook...|Open notebook' => 'Abrir _outro caderno...|Abrir caderno',
  '_Open link' => 'Abrir _ligazón',
  '_Overwrite' => 'S_obrescribir',
  '_Page' => '_Páxina',
  '_Page Changes...' => 'Cambios na _páxina',
  '_Parent|Go to parent page' => '_Subir|Ir á páxina superior',
  '_Paste|Paste' => '_Pegar|Pegar',
  '_Preview' => 'Vista _previa',
  '_Previous' => '_Anterior',
  '_Previous in index|Go to previous page' => '_Anterior no índice|Ir á páxina anterior',
  '_Properties' => '_Propiedades',
  '_Quit|Quit' => '_Saír|Saír',
  '_Recent pages|.' => 'Páxinas recentes|.',
  '_Redo|Redo' => '_Refacer|Refacer',
  '_Reload|Reload page' => '_Recargar|Recargar páxina',
  '_Rename' => '_Renomear',
  '_Rename Page...|Rename page' => '_Renomear páxina...|Renomear páxina',
  '_Replace' => '_Substituír',
  '_Replace...|Find and Replace' => '_Substituir...|Procurar e substituir',
  '_Reset' => '_Restablecer',
  '_Restore Version...' => '_Restaurar Versión...',
  '_Save Copy' => '_Gardar copia',
  '_Save a copy...' => '_Gardar unha copia...',
  '_Save|Save page' => '_Gardar|Gardar páxina',
  '_Screenshot...|Insert screenshot' => 'Captura de _pantalla...|Inserir captura de pantalla',
  '_Search...|Search' => 'Pro_curar...|Procurar',
  '_Search|' => '_Procurar|',
  '_Send To...|Mail page' => 'En_viar a...|Enviar a páxina por correo electrónico',
  '_Statusbar|Show statusbar' => 'Barra de e_stado|Amosar a barra de estado',
  '_TODO List...|Open TODO List' => 'Lista de _tarefas...|Abrir a lista de tarefas',
  '_Today' => '_Hoxe',
  '_Toolbar|Show toolbar' => 'Barra de Ferramen_tas|Amosar a barra de ferramentas',
  '_Tools|' => 'Ferramen_tas|',
  '_Underline|Underline' => '_Subliñado|Subliñado',
  '_Undo|Undo' => '_Desfacer|Desfacer',
  '_Update links in this page' => 'Actualizar _enlaces nesta páxina',
  '_Update {number} page linking here' => [
    '_Actualizar {number} páxina que liga aquí',
    '_Actualizar {number} páxinas que ligan aquí'
  ],
  '_Verbatim|Verbatim' => '_Verbatim|Verbatim',
  '_Versions...|Versions' => '_Versións...|Versións',
  '_View|' => '_Ver|',
  '_Word Count|Word count' => '_Contar palabras|Contar palabras',
  'other...' => 'Outro...',
  '{name}_(Copy)' => '{name}_(Copia)',
  '{number} _Back link' => [
    '{number} ligazón _inversa',
    '{number} ligazóns _inversas'
  ],
  '{number} item total' => [
    '{number} artigo en total',
    '{number} artigos en total'
  ]
};
